@@ -43,7 +43,9 @@
 (export gnc:option-default-getter)
 (export gnc:option-generate-restore-form)
 (export gnc:option-scm->kvp)
+(export gnc:set-option-scm->kvp)
 (export gnc:option-kvp->scm)
+(export gnc:set-option-kvp->scm)
 (export gnc:option-value-validator)
 (export gnc:option-data)
 (export gnc:option-data-fns)
